@@ -441,9 +441,9 @@ impl Command {
     }
 
     pub(crate) fn find_subcommand(&self, name: &str) -> Option<&Self> {
-        self.subcommands.iter().find(|subcmd| {
-            return subcmd.list_names().iter().any(|v| v == name);
-        })
+        self.subcommands
+            .iter()
+            .find(|subcmd| subcmd.list_names().iter().any(|v| v == name))
     }
 
     pub(crate) fn find_default_subcommand(&self) -> Option<&Self> {
@@ -498,7 +498,11 @@ impl Command {
 
         // auto alias if command name contains `_`
         if let Some(name) = self.name.clone() {
-            let compatible_name = name.replace('_', "-");
+            let compatible_name = if !name.starts_with('_') {
+                name.replace("_", "-")
+            } else {
+                name.clone()
+            };
             if compatible_name != name {
                 match self.aliases.as_mut() {
                     Some((aliaes, _)) => aliaes.insert(0, compatible_name),
